@@ -3,10 +3,10 @@ package App::NDTools::NDTool;
 use strict;
 use warnings FATAL => 'all';
 
-use Encode::Locale qw(decode_argv);
 use App::NDTools::INC;
 use App::NDTools::Slurp qw(s_dump s_load);
-use Getopt::Long qw(:config bundling);
+use Encode::Locale qw(decode_argv);
+use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Log::Log4Cli;
 use Struct::Path 0.80 qw(path);
 
@@ -83,11 +83,11 @@ sub load_struct {
 }
 
 sub new {
-    my $self = bless {}, shift;
+    my $self = bless { ARGV => \@_ }, shift;
     $self->{OPTS} = $self->defaults();
 
     decode_argv(Encode::FB_CROAK);
-    unless (GetOptions ($self->arg_opts)) {
+    unless (GetOptionsFromArray ($self->{ARGV}, $self->arg_opts)) {
         $self->usage;
         die_fatal "Unsupported opts used", 1;
     }
